import json
import os
from typing import Union
from tqdm import tqdm
from datasets import load_dataset, Dataset


def read_jsonl(file_path: str, use_tqdm=False):
    with open(file_path, "r") as file:
        if use_tqdm:
            lines = file.readlines()

            file_name = os.path.basename(file_path)
            results = []
            for line in tqdm(lines, desc=file_name):
                results.append(json.loads(line))
            return results
        else:
            return [json.loads(line) for line in file]


def load_jsonl(file_path: str, **kwargs) -> Union[Dataset, list]:
    try:
        dataset = load_dataset("json", data_files=[file_path], **kwargs)["train"]
        return dataset
    except Exception as e:
        print(f"Failed to load JSONL from {file_path} with {e}")
        return read_jsonl(file_path)


def read_json(file_path: str):
    with open(file_path, "r") as file:
        return json.loads(file.read())


def write_jsonl(file_path: str, data_list: list, use_tqdm=False):
    with open(file_path, "w") as file:
        file_name = os.path.basename(file_path)
        for item in tqdm(data_list, desc=file_name, disable=not use_tqdm):
            file.write(json.dumps(item, ensure_ascii=False) + "\n")


def write_json(file_path: str, data_dict: dict):
    with open(file_path, "w") as file:
        file.write(json.dumps(data_dict, ensure_ascii=False))



import fire
import os
from neetils import load_jsonl, write_json
import pandas as pd


class Converter(object):
    def _get_format(self, output_file: str):
        ext = os.path.splitext(output_file)[1]
        if ext == ".json":
            return "json"
        elif ext == ".csv":
            return "csv"
        elif ext == ".tsv":
            return "tsv"
        elif ext == ".xlsx":
            return "xlsx"
        else:
            raise ValueError(f"Unsupported file format {ext}")

    def convert(
        self,
        input_file: str,
        output_file: str,
        format: str = None,
        overwrite: bool = True,
    ) -> str:
        """
        Convert the input JSONL file to the specified format.

        Args:
            input_file (str): The path to the input JSONL file.
            output_file (str): The path to the output
            format (str): The format to convert the JSONL file to. If None, it will be determined based on the extension of the output file.
        """
        data = load_jsonl(input_file)
        if format is None:
            format = self._get_format(output_file)
        if os.path.exists(output_file) and not overwrite:
            raise FileExistsError(f"Output file {output_file} already exists")

        if format == "json":
            write_json(output_file, data)
        elif format == "csv" or format == "tsv":
            pd.DataFrame(data).to_csv(
                output_file, index=False, sep="\t" if format == "tsv" else ","
            )
        elif format == "xlsx":
            pd.DataFrame(data).to_excel(output_file, index=False)
        else:
            raise ValueError(f"Unsupported format: {format}")

        return output_file


def main():
    fire.Fire(Converter)
